#!/bin/sh
#
# mkmsg1N.sh 
#
# Build an msg1N pfile from a list file - generic version
#
# 1999jan01 dpwe@icsi.berkeley.edu
# $Header: $

set -e

# Can setenv SR to choose diff base sampling rate
: ${SR:=16000}
# Can setenv FILECMD to convert list entries to filenames
: ${FILECMD:=}

# FILECMD="bn_file dataset=16k %u" 

# Input list of soundfiles, no ranges
if [ -z "$1" ]; then
    BASENAME=allsegs
else
    BASENAME=$1
fi

LISTFILE=$BASENAME.list

# Feature name for final output
FTRNAME=msg1N

if [ ! -r $LISTFILE ]; then
   echo "$0: cannot read listfile $LISTFILE"
   echo "usage: $0 <basename>"
   echo "  will read <basename>.list, a list of audio files"
   echo "  and write <basename>-$FTRNAME.pf, a feature file."
   exit 1
fi

# Directory containing the filter specs (*.sos)
FILTSPECDIR=.

# Use tee(1) and a named pipe so we only have to resample once, but 
# can feed the result to both invocations of modspec.  This saves 
# a lot of time, since sndrsmp takes over twice as long as modspec (!!)
PIPE=/tmp/mkpf$$.pipe
mknod $PIPE p

wavs2onlaudio sf=$SR zeropad=72 \
    infilename=$LISTFILE filecmd=$FILECMD \
| sndrsmp -S PCM/R${SR}Abb -T PCM/Abb -r 8000 - - \
| tee $PIPE \
| modspec \
    -efilt $FILTSPECDIR/lo0_hi16.sos \
    -agctau1 160 -agctau2 320 \
| feacat -width 14 -ip onl -op pfile -out $BASENAME-msg1a.pf \
& modspec \
    -efilt $FILTSPECDIR/lo2_hi16.sos \
    -agctau1 160 -agctau2 640 \
  < $PIPE \
| feacat -width 14 -ip onl -op pfile -out $BASENAME-msg1b.pf

rm $PIPE

pfile_merge -i1 $BASENAME-msg1a.pf -i2 $BASENAME-msg1b.pf -o $BASENAME-msg1.pf
rm $BASENAME-msg1a.pf $BASENAME-msg1b.pf
pfile_normutts -i $BASENAME-msg1.pf -o $BASENAME-$FTRNAME.pf
rm $BASENAME-msg1.pf

